@@ -14,7 +14,7 @@ int main() {
   /* char *server_name = "iel2.engr.ucdavis.edu"; */
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
 
   agency = MC_Initialize(local_port, &options);
   printf("Press key to send the squad leader...\n");
