@@ -9,9 +9,15 @@ int algorithm(void* boo);
 int main() {
     MCAgency_t agency;
     int local_port = 5050;
+    MCAgencyOptions_t options;
 
-    agency = MC_Initialize(local_port, NULL);
-    
+    MC_InitializeAgencyOptions(&options);
+
+    MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+
+    agency = MC_Initialize(local_port, &options);
+
+    printf("Starting algorithm...\n");
     MC_Steer(
         agency,
         &algorithm,
