@@ -78,6 +78,14 @@ namespace LibMCInterop
             public int[] iarr;
             public int uses;
             public String name;
+
+            public override string ToString()
+            {
+                return "i = " + i.ToString() + "\n" +
+                       "d = " + d.ToString() + "\n" +
+                       "uses = " + uses.ToString() + "\n" +
+                       "name = " + name;
+            }
         };
 
         /**
@@ -96,6 +104,14 @@ namespace LibMCInterop
             public IntPtr s; // pointer to struct struct1_t
             public int uses;
             public String name;
+
+            public override string ToString()
+            {
+                return "i = " + i.ToString() + "\n" +
+                       "d = " + d.ToString() + "\n" +
+                       "uses = " + uses.ToString() + "\n" +
+                       "name = " + name;
+            }
         };
 
         /**
@@ -107,10 +123,10 @@ namespace LibMCInterop
          * 
          * \param     callback Fx delegate to use as callback
          */
-        public static void SetCallBack(Fx callback)
+        public static void SetFxCallBack(Fx callback)
         {
-            IntPtr f = Marshal.GetFunctionPointerForDelegate(callback);
-            Cs2Ch.setCallback(f);
+            //IntPtr f = Marshal.GetFunctionPointerForDelegate(callback);
+            Cs2Ch.setFxCallback(callback);//f);
         }
 
         /**
@@ -122,10 +138,10 @@ namespace LibMCInterop
          * 
          * \param     callback Fy delegate to use as callback
          */
-        public static void SetFunc2CallBack(Fy callback)
+        public static void SetFyCallBack(Fy callback)
         {
-            IntPtr f = Marshal.GetFunctionPointerForDelegate(callback);
-            Cs2Ch.setFunc2Callback(f);
+            //IntPtr f = Marshal.GetFunctionPointerForDelegate(callback);
+            Cs2Ch.setFyCallback(callback);//f);
         }
 
         public static struct1_t NewStruct1()
@@ -136,10 +152,31 @@ namespace LibMCInterop
             return s;
         }
 
-        public static struct2_t Func3(ref struct1_t s1)
+        public static struct2_t Func3(ref struct1_t s1, out struct1_t embedded_s1)
         {
+            embedded_s1 = new struct1_t();
             IntPtr sp = func3(ref s1);
             if (sp != IntPtr.Zero)
+            {
+                struct2_t s = (struct2_t)Marshal.PtrToStructure(sp, typeof(struct2_t));
+                /*
+                 * This needs help: sp returned by func 3 has a pointer to a struct1_t
+                 * that was set to the "ref s1" passed into func3. "ref s1" is not a valid
+                 * pointer, so how do we handle that? Temporarily, the embedded IntPtr in
+                 * s is set to zero to avoid freeing problems.
+                 * */
+                embedded_s1 = (struct1_t)Marshal.PtrToStructure(s.s, typeof(struct1_t));
+                free_struct2(sp);
+                return s;
+            }
+            else
+                return new struct2_t();
+        }
+
+        public static struct2_t Func4(struct1_t s1)
+        {
+            IntPtr sp = func4(s1);
+            if (sp != IntPtr.Zero)
             {
                 struct2_t s = (struct2_t)Marshal.PtrToStructure(sp, typeof(struct2_t));
                 free_struct2(sp);
@@ -166,25 +203,27 @@ namespace LibMCInterop
         [DllImport(dlfile)]
         public static extern double func2(ref struct1_t s1, ref struct2_t s2);
         [DllImport(dlfile)]
-        public static extern void callFptr(String s);
+        public static extern void callFxCallback(String s);
         [DllImport(dlfile)]
-        public static extern void callFunc2(ref arg_struct arg);
+        public static extern void callFyCallback(ref arg_struct arg);
 
         // These functions can be called directly, but wrappers are provided as well.
         [DllImport(dlfile)]
-        public static extern void setCallback(IntPtr f);
+        public static extern void setFxCallback(Fx f);
         [DllImport(dlfile)]
-        public static extern void setFunc2Callback(IntPtr f);
+        public static extern void setFyCallback(Fy f);
 
         // These functions require manual marshalling or involve unmanaged dynamic memory, so they will be wrapped
         [DllImport(dlfile)]
-        internal static extern IntPtr func3(ref struct1_t s1);
+        private static extern IntPtr func3(ref struct1_t s1);
         [DllImport(dlfile)]
-        internal static extern IntPtr new_struct1();
+        private static extern IntPtr func4(struct1_t s1);
         [DllImport(dlfile)]
-        internal static extern void free_struct1(IntPtr s);
+        private static extern IntPtr new_struct1();
         [DllImport(dlfile)]
-        internal static extern void free_struct2(IntPtr s);
+        private static extern void free_struct1(IntPtr s);
+        [DllImport(dlfile)]
+        private static extern void free_struct2(IntPtr s);
 
     }
 }
