@@ -1,6 +1,6 @@
  /* SVN FILE INFO
- * $Revision: 230 $ : Last Committed Revision
- * $Date: 2008-10-24 15:47:36 -0700 (Fri, 24 Oct 2008) $ : Last Committed Date */
+ * $Revision: 249 $ : Last Committed Revision
+ * $Date: 2008-12-12 17:33:25 -0800 (Fri, 12 Dec 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -241,6 +241,9 @@ agent_Initialize(
   GetSystemTime( &(agent->arrival_time) );
 #endif
 
+  agent->home = NULL;
+  agent->sender = NULL;
+
   /* set flags */
   agent->orphan = 0;
   agent->agent_script_ready = 1;
@@ -335,6 +338,9 @@ agent_Destroy(agent_p agent)
   if (agent->home != NULL) {
     free(agent->home);
   }
+  if (agent->sender != NULL) {
+    free(agent->sender);
+  }
   /* Terminate the agent datastate memory */
   MUTEX_DESTROY(agent->lock);
   if (agent->agent_status == MC_AGENT_NEUTRAL) {
