@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 230 $ : Last Committed Revision
- * $Date: 2008-10-24 15:47:36 -0700 (Fri, 24 Oct 2008) $ : Last Committed Date */
+ * $Revision: 249 $ : Last Committed Revision
+ * $Date: 2008-12-12 17:33:25 -0800 (Fri, 12 Dec 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -1273,7 +1273,7 @@ MC_RetrieveAgent(MCAgency_t attr) /*{{{*/
      the specified attributes, return value is NULL. */
 {
   int i;
-  MCAgent_t agent=NULL, ret;
+  MCAgent_t agent=NULL;
   MUTEX_LOCK(attr->mc_platform->agent_queue->lock);
   for (i = 0; i < attr->mc_platform->agent_queue->size; i++) {
     agent = ListSearch(
@@ -1290,10 +1290,8 @@ MC_RetrieveAgent(MCAgency_t attr) /*{{{*/
     MUTEX_UNLOCK(attr->mc_platform->agent_queue->lock);
     return NULL;
   }
-  ret = (MCAgent_t)malloc(sizeof(agent_t));
-  *ret = *agent;
   MUTEX_UNLOCK(attr->mc_platform->agent_queue->lock);
-  return ret;
+  return agent;
 }/*}}}*/
 
 EXPORTMC char * 
@@ -1449,7 +1447,9 @@ MC_SendAgentMigrationMessageFile(MCAgency_t attr,  /*{{{*/
   FILE *fp;
   int ret;
   message_p message;
+  agent_t *agent;
   extern mc_platform_p g_mc_platform;
+  mc_platform_p platform;
   buf = NULL;
   filestat.st_size = 0;
   stat(filename, &filestat);
@@ -1461,54 +1461,44 @@ MC_SendAgentMigrationMessageFile(MCAgency_t attr,  /*{{{*/
     return 1;
   }
 
+  if (attr == NULL) {
+    platform = g_mc_platform;
+  } else {
+    platform = attr->mc_platform;
+  }
+
   fp = fopen(filename, "r");
   fread((void*)buf, filestat.st_size, 1, fp);
   fclose(fp);
 
-  if (attr!=NULL) {
-    message = message_New();
-    if( 
-        message_InitializeFromString
-        (
-         attr->mc_platform,
-         message,
-         buf,
-         hostname,
-         port,
-         "ams"
-        )
+  message = message_New();
+  if( 
+      message_InitializeFromString
+      (
+       platform,
+       message,
+       buf,
+       hostname,
+       port,
+       "ams"
       )
-    {
-      message_Destroy(message);
-    } else {
-      ret = message_queue_Add
-        (
-         attr->mc_platform->message_queue,
-         message 
-        );
-    }
+    )
+  {
+    message_Destroy(message);
   } else {
-    message = message_New();
-    if(
-        message_InitializeFromString
-        (
-         g_mc_platform,
-         message,
-         buf,
-         hostname,
-         port,
-         "ams"
-        )
-      )
-    {
-      message_Destroy(message);
-    } else {
-      ret = message_queue_Add
-        (
-         g_mc_platform->message_queue,
-         message
-        );
+    /* Here, we wish to fully parse the message and create a fully qualified
+     * agent, then let the agency send the agent. */
+    agent = agent_Initialize( platform, message, rand() );
+    if (agent == NULL) {
+      fprintf(stderr, "Error initializing agent. %s:%d", __FILE__, __LINE__);
     }
+    agent->agent_status = MC_WAIT_MESSGSEND;
+    agent_queue_Add( platform->agent_queue, agent);
+    /* Set the ams to run */
+    MUTEX_LOCK(platform->ams->runflag_lock);
+    platform->ams->run = 1;
+    COND_BROADCAST(platform->ams->runflag_cond);
+    MUTEX_UNLOCK(platform->ams->runflag_lock);
   }
   free(buf);
   return ret;
