@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 174 $ : Last Committed Revision
- * $Date: 2008-06-24 10:50:29 -0700 (Tue, 24 Jun 2008) $ : Last Committed Date */
+ * $Revision: 249 $ : Last Committed Revision
+ * $Date: 2008-12-12 17:33:25 -0800 (Fri, 12 Dec 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -597,6 +597,18 @@ message_InitializeFromString(
           destination_host, destination_port, __FILE__, __LINE__ );
     }
   }
+  message->xml_root = mxmlLoadString
+    (
+     NULL, 
+     message->message_body,
+     MXML_NO_CALLBACK
+    );
+  if (message_xml_parse(message)) {
+    fprintf(stderr, "Error parsing message at %s:%d.\n",
+        __FILE__, __LINE__);
+    message_Destroy(message);
+    return MC_ERR_PARSE;
+  }
 
   return MC_SUCCESS;
 }
@@ -747,12 +759,15 @@ message_Send(message_p message)
         mtp_http->response_code, mtp_http->response_string );
   }
 
+  mtp_http_Destroy(mtp_http);
+
 #ifndef _WIN32
   close(skt);
 #else
   closesocket(skt);
 #endif
   free(buf);
+  free(buffer);
   return 0;
 }
 
