@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 205 $ : Last Committed Revision
- * $Date: 2008-07-11 17:08:41 -0700 (Fri, 11 Jul 2008) $ : Last Committed Date */
+ * $Revision: 249 $ : Last Committed Revision
+ * $Date: 2008-12-12 17:33:25 -0800 (Fri, 12 Dec 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -76,6 +76,7 @@ mtp_http_Destroy(mtp_http_p http)
   }
   SAFE_FREE(http->content);
   SAFE_FREE(http->boundary);
+  SAFE_FREE(http->response_string);
   SAFE_FREE(http);
 #undef SAFE_FREE
   return 0;
@@ -473,6 +474,7 @@ mtp_http_Parse(struct mtp_http_s* http, const char* string)
 
   if (http->message_parts == 1) { 
     http->content = (struct mtp_http_content_s*)malloc(sizeof(struct mtp_http_content_s));
+    memset(http->content, 0, sizeof(struct mtp_http_content_s));
     /* Copy rest of contents into the data member */
     if (line != NULL) {
       http->content->data = (void*)malloc
@@ -632,7 +634,7 @@ const char* http_ParseRequest(
     cur = http_GetToken(cur, &token);
     sscanf(token, "%d", &http->response_code);
     /* And now a status string */
-    len = strstr(cur, "\r\n") - 1;
+    len = strstr(cur, "\r\n") - cur + 1;
     http->response_string = malloc(
         sizeof(char) * (len +1) );
     strncpy(
