@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 232 $ : Last Committed Revision
- * $Date: 2008-11-03 11:44:57 -0800 (Mon, 03 Nov 2008) $ : Last Committed Date */
+ * $Revision: 249 $ : Last Committed Revision
+ * $Date: 2008-12-12 17:33:25 -0800 (Fri, 12 Dec 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -131,6 +131,15 @@ agent_xml_parse__agent_data
     return err_code;
   }
 
+  xml_parser->node = xml_get_child(
+      agent_data_node,
+      "SENDER",
+      1
+      );
+  if( (err_code = agent_xml_parse__sender(agent, xml_parser)) ) {
+    return err_code;
+  }
+
   xml_parser->node = xml_get_child(
       agent_data_node,
       "TASKS",
@@ -221,6 +230,34 @@ agent_xml_parse__home(agent_p agent, xml_parser_p xml_parser)
   return MC_SUCCESS;
 }
 
+/* *** */
+/* agent_xml_parse__sender */
+error_code_t
+agent_xml_parse__sender(agent_p agent, xml_parser_p xml_parser)
+{
+  char *text;
+  const mxml_node_t* sender_node;
+  if (xml_parser->node == NULL) {
+    /* This is fine: sender field is optional for now */
+    agent->sender = NULL;
+    return MC_SUCCESS;
+  }
+  sender_node = xml_parser->node;
+  text = xml_get_text( sender_node );
+  /* If there is no text, just return... */
+  CHECK_NULL(text, agent->sender=NULL;return MC_SUCCESS; );
+
+  agent->sender = (char*)malloc(
+      sizeof(char)*(strlen(text)+1)
+      );
+  strcpy(
+      agent->sender,
+      text
+      );
+  free(text);
+  return MC_SUCCESS;
+}
+
 /* *** */
 /* agent_xml_parse__tasks */
 error_code_t
